@@ -39,9 +39,9 @@ tvROC.jm <- function (object, newdata, Tstart, Thoriz = NULL, Dt = NULL, ...) {
     test1 <- newdata[[Time_var]] < Thoriz & newdata[[event_var]] == 1
     if (!any(test1))
         stop("it seems that there are no events in the interval [Tstart, Thoriz).")
-    test2 <- newdata[[Time_var]] > Thoriz & newdata[[event_var]] == 1
-    if (!any(test2))
-        stop("it seems that there are no events after Thoriz.")
+    #test2 <- newdata[[Time_var]] > Thoriz & newdata[[event_var]] == 1
+    #if (!any(test2))
+    #    stop("it seems that there are no events after Thoriz.")
     newdata2 <- newdata
     newdata2[[Time_var]] <- Tstart
     newdata2[[event_var]] <- 0
@@ -182,9 +182,9 @@ tvAUC.jm <- function (object, newdata, Tstart, Thoriz = NULL, Dt = NULL, ...) {
     test1 <- newdata[[Time_var]] < Thoriz & newdata[[event_var]] == 1
     if (!any(test1))
         stop("it seems that there are no events in the interval [Tstart, Thoriz).")
-    test2 <- newdata[[Time_var]] > Thoriz & newdata[[event_var]] == 1
-    if (!any(test2))
-        stop("it seems that there are no events after Thoriz.")
+    #test2 <- newdata[[Time_var]] > Thoriz & newdata[[event_var]] == 1
+    #if (!any(test2))
+    #    stop("it seems that there are no events after Thoriz.")
     newdata2 <- newdata
     newdata2[[Time_var]] <- Tstart
     newdata2[[event_var]] <- 0
@@ -356,9 +356,9 @@ calibration_plot <- function (object, newdata, Tstart, Thoriz = NULL,
     test1 <- newdata[[Time_var]] < Thoriz & newdata[[event_var]] == 1
     if (!any(test1))
         stop("it seems that there are no events in the interval [Tstart, Thoriz).")
-    test2 <- newdata[[Time_var]] > Thoriz & newdata[[event_var]] == 1
-    if (!any(test2))
-        stop("it seems that there are no events after Thoriz.")
+    #test2 <- newdata[[Time_var]] > Thoriz & newdata[[event_var]] == 1
+    #if (!any(test2))
+    #    stop("it seems that there are no events after Thoriz.")
     newdata2 <- newdata
     newdata2[[Time_var]] <- Tstart
     newdata2[[event_var]] <- 0
@@ -453,9 +453,9 @@ tvBrier <- function (object, newdata, Tstart, Thoriz = NULL, Dt = NULL, ...) {
     test1 <- newdata[[Time_var]] < Thoriz & newdata[[event_var]] == 1
     if (!any(test1))
         stop("it seems that there are no events in the interval [Tstart, Thoriz).")
-    test2 <- newdata[[Time_var]] > Thoriz & newdata[[event_var]] == 1
-    if (!any(test2))
-        stop("it seems that there are no events after Thoriz.")
+    #test2 <- newdata[[Time_var]] > Thoriz & newdata[[event_var]] == 1
+    #if (!any(test2))
+    #    stop("it seems that there are no events after Thoriz.")
     newdata2 <- newdata
     newdata2[[Time_var]] <- Tstart
     newdata2[[event_var]] <- 0
